from pydantic import BaseModel


class EntryPointDto(BaseModel):
    """Представляет точку прохода в СКУД АПК «Бастион-2»"""
    servID: str  # Идентификатор сервера – владельца точки прохода
    subDeviceNo: int  # Идентификатор устройства на сервере
    subDeviceName: str  # Имя точки прохода


class AccessLevelDto(BaseModel):
    """Тип AccessLevel представляет собой набор данных уровня доступа. Объект типа AccessLevel
    используется в методе создания/редактирования пропуска/заявки на пропуск PutPass, в методе
    получения списка пропусков GetPasses, также в методе получения списка уровней доступа
    GetAccessLevels """
    servID: str  # Идентификатор сервера – владельца точки прохода
    id: int  # Идентификатор уровня доступа
    name: str  # Имя уровня доступа


class ControlAreaDto(BaseModel):
    """Тип ControlArea представляет собой набор данных областей контроля. Используется в качестве
выходного параметра метода GetControlAreas, возвращающего коллекцию областей контроля, а
также является полем типа данных Attendance."""
    servId: str  # Идентификатор сервера – владельца области контроля
    id: int  # Идентификатор области контроля на сервере
    name: str  # Имя области контроля


class AccessPointDto(BaseModel):
    """AccessPoint – объект, представляющий точку доступа (дверь, ворота, турникет) в СКУД АПК
    «Бастион-2». Используется в качестве выходного параметра в методе GetAccessPoints,
    возвращающем коллекцию точек доступа."""
    sServID: str  # Идентификатор сервера – владельца точки прохода
    sSubDeviceNo: int  # Идентификатор устройства на сервере
    sSubDeviceName: str  # Имя точки прохода
